@@ -1,13 +1,9 @@
-//
-// Sysinfo
-//
-// Copyright (c) 2017 Guillaume Gomez
-//
+// Take a look at the license at the top of the repository in the LICENSE file.
 
+use crate::{NetworkExt, NetworksExt, Pid, Process, ProcessExt, ProcessorExt, System, SystemExt};
 use libc::{self, c_char, c_float, c_uint, c_void, pid_t, size_t};
 use std::borrow::BorrowMut;
 use std::ffi::CString;
-use {NetworkExt, NetworksExt, Process, ProcessExt, ProcessorExt, System, SystemExt};
 
 /// Equivalent of [`System`][crate::System] struct.
 pub type CSystem = *mut c_void;
@@ -15,7 +11,7 @@ pub type CSystem = *mut c_void;
 pub type CProcess = *const c_void;
 /// C string returned from `CString::into_raw`.
 pub type RString = *const c_char;
-/// Callback used by [`get_processes`][crate::System#method.get_processes].
+/// Callback used by [`get_processes`][crate::System#method.processes].
 pub type ProcessLoop = extern "C" fn(pid: pid_t, process: CProcess, data: *mut c_void) -> bool;
 
 /// Equivalent of [`System::new()`][crate::System#method.new].
@@ -38,72 +34,84 @@ pub extern "C" fn sysinfo_destroy(system: CSystem) {
 #[no_mangle]
 pub extern "C" fn sysinfo_refresh_system(system: CSystem) {
     assert!(!system.is_null());
-    let mut system: Box<System> = unsafe { Box::from_raw(system as *mut System) };
-    {
-        let system: &mut System = system.borrow_mut();
-        system.refresh_system();
+    unsafe {
+        let mut system: Box<System> = Box::from_raw(system as *mut System);
+        {
+            let system: &mut System = system.borrow_mut();
+            system.refresh_system();
+        }
+        Box::into_raw(system);
     }
-    Box::into_raw(system);
 }
 
 /// Equivalent of [`System::refresh_memory()`][crate::System#method.refresh_memory].
 #[no_mangle]
 pub extern "C" fn sysinfo_refresh_memory(system: CSystem) {
     assert!(!system.is_null());
-    let mut system: Box<System> = unsafe { Box::from_raw(system as *mut System) };
-    {
-        let system: &mut System = system.borrow_mut();
-        system.refresh_memory();
+    unsafe {
+        let mut system: Box<System> = Box::from_raw(system as *mut System);
+        {
+            let system: &mut System = system.borrow_mut();
+            system.refresh_memory();
+        }
+        Box::into_raw(system);
     }
-    Box::into_raw(system);
 }
 
 /// Equivalent of [`System::refresh_cpu()`][crate::System#method.refresh_cpu].
 #[no_mangle]
 pub extern "C" fn sysinfo_refresh_cpu(system: CSystem) {
     assert!(!system.is_null());
-    let mut system: Box<System> = unsafe { Box::from_raw(system as *mut System) };
-    {
-        let system: &mut System = system.borrow_mut();
-        system.refresh_cpu();
+    unsafe {
+        let mut system: Box<System> = Box::from_raw(system as *mut System);
+        {
+            let system: &mut System = system.borrow_mut();
+            system.refresh_cpu();
+        }
+        Box::into_raw(system);
     }
-    Box::into_raw(system);
 }
 
 /// Equivalent of [`System::refresh_components()`][crate::System#method.refresh_temperatures].
 #[no_mangle]
 pub extern "C" fn sysinfo_refresh_components(system: CSystem) {
     assert!(!system.is_null());
-    let mut system: Box<System> = unsafe { Box::from_raw(system as *mut System) };
-    {
-        let system: &mut System = system.borrow_mut();
-        system.refresh_components();
+    unsafe {
+        let mut system: Box<System> = Box::from_raw(system as *mut System);
+        {
+            let system: &mut System = system.borrow_mut();
+            system.refresh_components();
+        }
+        Box::into_raw(system);
     }
-    Box::into_raw(system);
 }
 
 /// Equivalent of [`System::refresh_all()`][crate::System#method.refresh_all].
 #[no_mangle]
 pub extern "C" fn sysinfo_refresh_all(system: CSystem) {
     assert!(!system.is_null());
-    let mut system: Box<System> = unsafe { Box::from_raw(system as *mut System) };
-    {
-        let system: &mut System = system.borrow_mut();
-        system.refresh_all();
+    unsafe {
+        let mut system: Box<System> = Box::from_raw(system as *mut System);
+        {
+            let system: &mut System = system.borrow_mut();
+            system.refresh_all();
+        }
+        Box::into_raw(system);
     }
-    Box::into_raw(system);
 }
 
 /// Equivalent of [`System::refresh_processes()`][crate::System#method.refresh_processes].
 #[no_mangle]
 pub extern "C" fn sysinfo_refresh_processes(system: CSystem) {
     assert!(!system.is_null());
-    let mut system: Box<System> = unsafe { Box::from_raw(system as *mut System) };
-    {
-        let system: &mut System = system.borrow_mut();
-        system.refresh_processes();
+    unsafe {
+        let mut system: Box<System> = Box::from_raw(system as *mut System);
+        {
+            let system: &mut System = system.borrow_mut();
+            system.refresh_processes();
+        }
+        Box::into_raw(system);
     }
-    Box::into_raw(system);
 }
 
 /// Equivalent of [`System::refresh_process()`][crate::System#method.refresh_process].
@@ -111,127 +119,147 @@ pub extern "C" fn sysinfo_refresh_processes(system: CSystem) {
 #[no_mangle]
 pub extern "C" fn sysinfo_refresh_process(system: CSystem, pid: pid_t) {
     assert!(!system.is_null());
-    let mut system: Box<System> = unsafe { Box::from_raw(system as *mut System) };
-    {
-        let system: &mut System = system.borrow_mut();
-        system.refresh_process(pid);
+    unsafe {
+        let mut system: Box<System> = Box::from_raw(system as *mut System);
+        {
+            let system: &mut System = system.borrow_mut();
+            system.refresh_process(Pid(pid));
+        }
+        Box::into_raw(system);
     }
-    Box::into_raw(system);
 }
 
 /// Equivalent of [`System::refresh_disks()`][crate::System#method.refresh_disks].
 #[no_mangle]
 pub extern "C" fn sysinfo_refresh_disks(system: CSystem) {
     assert!(!system.is_null());
-    let mut system: Box<System> = unsafe { Box::from_raw(system as *mut System) };
-    {
-        let system: &mut System = system.borrow_mut();
-        system.refresh_disks();
+    unsafe {
+        let mut system: Box<System> = Box::from_raw(system as *mut System);
+        {
+            let system: &mut System = system.borrow_mut();
+            system.refresh_disks();
+        }
+        Box::into_raw(system);
     }
-    Box::into_raw(system);
 }
 
 /// Equivalent of [`System::refresh_disks_list()`][crate::System#method.refresh_disks_list].
 #[no_mangle]
 pub extern "C" fn sysinfo_refresh_disks_list(system: CSystem) {
     assert!(!system.is_null());
-    let mut system: Box<System> = unsafe { Box::from_raw(system as *mut System) };
-    {
-        let system: &mut System = system.borrow_mut();
-        system.refresh_disks_list();
+    unsafe {
+        let mut system: Box<System> = Box::from_raw(system as *mut System);
+        {
+            let system: &mut System = system.borrow_mut();
+            system.refresh_disks_list();
+        }
+        Box::into_raw(system);
     }
-    Box::into_raw(system);
 }
 
-/// Equivalent of [`System::get_total_memory()`][crate::System#method.get_total_memory].
+/// Equivalent of [`System::get_total_memory()`][crate::System#method.total_memory].
 #[no_mangle]
 pub extern "C" fn sysinfo_get_total_memory(system: CSystem) -> size_t {
     assert!(!system.is_null());
-    let system: Box<System> = unsafe { Box::from_raw(system as *mut System) };
-    let ret = system.get_total_memory() as size_t;
-    Box::into_raw(system);
-    ret
+    unsafe {
+        let system: Box<System> = Box::from_raw(system as *mut System);
+        let ret = system.total_memory() as size_t;
+        Box::into_raw(system);
+        ret
+    }
 }
 
-/// Equivalent of [`System::get_free_memory()`][crate::System#method.get_free_memory].
+/// Equivalent of [`System::get_free_memory()`][crate::System#method.free_memory].
 #[no_mangle]
 pub extern "C" fn sysinfo_get_free_memory(system: CSystem) -> size_t {
     assert!(!system.is_null());
-    let system: Box<System> = unsafe { Box::from_raw(system as *mut System) };
-    let ret = system.get_free_memory() as size_t;
-    Box::into_raw(system);
-    ret
+    unsafe {
+        let system: Box<System> = Box::from_raw(system as *mut System);
+        let ret = system.free_memory() as size_t;
+        Box::into_raw(system);
+        ret
+    }
 }
 
-/// Equivalent of [`System::get_used_memory()`][crate::System#method.get_used_memory].
+/// Equivalent of [`System::get_used_memory()`][crate::System#method.used_memory].
 #[no_mangle]
 pub extern "C" fn sysinfo_get_used_memory(system: CSystem) -> size_t {
     assert!(!system.is_null());
     let system: Box<System> = unsafe { Box::from_raw(system as *mut System) };
-    let ret = system.get_used_memory() as size_t;
+    let ret = system.used_memory() as size_t;
     Box::into_raw(system);
     ret
 }
 
-/// Equivalent of [`System::get_total_swap()`][crate::System#method.get_total_swap].
+/// Equivalent of [`System::get_total_swap()`][crate::System#method.total_swap].
 #[no_mangle]
 pub extern "C" fn sysinfo_get_total_swap(system: CSystem) -> size_t {
     assert!(!system.is_null());
-    let system: Box<System> = unsafe { Box::from_raw(system as *mut System) };
-    let ret = system.get_total_swap() as size_t;
-    Box::into_raw(system);
-    ret
+    unsafe {
+        let system: Box<System> = Box::from_raw(system as *mut System);
+        let ret = system.total_swap() as size_t;
+        Box::into_raw(system);
+        ret
+    }
 }
 
-/// Equivalent of [`System::get_free_swap()`][crate::System#method.get_free_swap].
+/// Equivalent of [`System::get_free_swap()`][crate::System#method.free_swap].
 #[no_mangle]
 pub extern "C" fn sysinfo_get_free_swap(system: CSystem) -> size_t {
     assert!(!system.is_null());
-    let system: Box<System> = unsafe { Box::from_raw(system as *mut System) };
-    let ret = system.get_free_swap() as size_t;
-    Box::into_raw(system);
-    ret
+    unsafe {
+        let system: Box<System> = Box::from_raw(system as *mut System);
+        let ret = system.free_swap() as size_t;
+        Box::into_raw(system);
+        ret
+    }
 }
 
-/// Equivalent of [`System::get_used_swap()`][crate::System#method.get_used_swap].
+/// Equivalent of [`System::get_used_swap()`][crate::System#method.used_swap].
 #[no_mangle]
 pub extern "C" fn sysinfo_get_used_swap(system: CSystem) -> size_t {
     assert!(!system.is_null());
-    let system: Box<System> = unsafe { Box::from_raw(system as *mut System) };
-    let ret = system.get_used_swap() as size_t;
-    Box::into_raw(system);
-    ret
+    unsafe {
+        let system: Box<System> = Box::from_raw(system as *mut System);
+        let ret = system.used_swap() as size_t;
+        Box::into_raw(system);
+        ret
+    }
 }
 
 /// Equivalent of
-/// `system::get_networks().iter().fold(0, |acc, (_, data)| acc + data.get_received() as size_t)`.
+/// `system::get_networks().iter().fold(0, |acc, (_, data)| acc + data.received() as size_t)`.
 #[no_mangle]
 pub extern "C" fn sysinfo_get_networks_received(system: CSystem) -> size_t {
     assert!(!system.is_null());
-    let system: Box<System> = unsafe { Box::from_raw(system as *mut System) };
-    let ret = system
-        .get_networks()
-        .iter()
-        .fold(0, |acc, (_, data)| acc + data.get_received() as size_t);
-    Box::into_raw(system);
-    ret
+    unsafe {
+        let system: Box<System> = Box::from_raw(system as *mut System);
+        let ret = system
+            .networks()
+            .iter()
+            .fold(0, |acc, (_, data)| acc + data.received() as size_t);
+        Box::into_raw(system);
+        ret
+    }
 }
 
 /// Equivalent of
-/// `system::get_networks().iter().fold(0, |acc, (_, data)| acc + data.get_transmitted() as size_t)`.
+/// `system::get_networks().iter().fold(0, |acc, (_, data)| acc + data.transmitted() as size_t)`.
 #[no_mangle]
 pub extern "C" fn sysinfo_get_networks_transmitted(system: CSystem) -> size_t {
     assert!(!system.is_null());
-    let system: Box<System> = unsafe { Box::from_raw(system as *mut System) };
-    let ret = system
-        .get_networks()
-        .iter()
-        .fold(0, |acc, (_, data)| acc + data.get_transmitted() as size_t);
-    Box::into_raw(system);
-    ret
+    unsafe {
+        let system: Box<System> = Box::from_raw(system as *mut System);
+        let ret = system
+            .networks()
+            .iter()
+            .fold(0, |acc, (_, data)| acc + data.transmitted() as size_t);
+        Box::into_raw(system);
+        ret
+    }
 }
 
-/// Equivalent of [`System::get_processors_usage()`][crate::System#method.get_processors_usage].
+/// Equivalent of [`System::get_processors_usage()`][crate::System#method.processors_usage].
 ///
 /// * `length` will contain the number of cpu usage added into `procs`.
 /// * `procs` will be allocated if it's null and will contain of cpu usage.
@@ -245,24 +273,24 @@ pub extern "C" fn sysinfo_get_processors_usage(
     if procs.is_null() || length.is_null() {
         return;
     }
-    let system: Box<System> = unsafe { Box::from_raw(system as *mut System) };
-    {
-        let processors = system.get_processors();
-        unsafe {
+    unsafe {
+        let system: Box<System> = Box::from_raw(system as *mut System);
+        {
+            let processors = system.processors();
             if (*procs).is_null() {
                 (*procs) = libc::malloc(::std::mem::size_of::<c_float>() * processors.len())
                     as *mut c_float;
             }
             for (pos, processor) in processors.iter().skip(1).enumerate() {
-                (*(*procs).offset(pos as isize)) = processor.get_cpu_usage();
+                (*(*procs).offset(pos as isize)) = processor.cpu_usage();
             }
             *length = processors.len() as c_uint - 1;
         }
+        Box::into_raw(system);
     }
-    Box::into_raw(system);
 }
 
-/// Equivalent of [`System::get_processes()`][crate::System#method.get_processes]. Returns an
+/// Equivalent of [`System::get_processes()`][crate::System#method.processes]. Returns an
 /// array ended by a null pointer. Must be freed.
 ///
 /// # /!\ WARNING /!\
@@ -276,24 +304,26 @@ pub extern "C" fn sysinfo_get_processes(
 ) -> size_t {
     assert!(!system.is_null());
     if let Some(fn_pointer) = fn_pointer {
-        let system: Box<System> = unsafe { Box::from_raw(system as *mut System) };
-        let len = {
-            let entries = system.get_processes();
-            for (pid, process) in entries {
-                if !fn_pointer(*pid, process as *const Process as CProcess, data) {
-                    break;
+        unsafe {
+            let system: Box<System> = Box::from_raw(system as *mut System);
+            let len = {
+                let entries = system.processes();
+                for (pid, process) in entries {
+                    if !fn_pointer(pid.0, process as *const Process as CProcess, data) {
+                        break;
+                    }
                 }
-            }
-            entries.len() as size_t
-        };
-        Box::into_raw(system);
-        len
+                entries.len() as size_t
+            };
+            Box::into_raw(system);
+            len
+        }
     } else {
         0
     }
 }
 
-/// Equivalent of [`System::get_process()`][crate::System#method.get_process].
+/// Equivalent of [`System::get_process()`][crate::System#method.process].
 ///
 /// # /!\ WARNING /!\
 ///
@@ -302,14 +332,16 @@ pub extern "C" fn sysinfo_get_processes(
 #[no_mangle]
 pub extern "C" fn sysinfo_get_process_by_pid(system: CSystem, pid: pid_t) -> CProcess {
     assert!(!system.is_null());
-    let system: Box<System> = unsafe { Box::from_raw(system as *mut System) };
-    let ret = if let Some(process) = system.get_process(pid) {
-        process as *const Process as CProcess
-    } else {
-        ::std::ptr::null()
-    };
-    Box::into_raw(system);
-    ret
+    unsafe {
+        let system: Box<System> = Box::from_raw(system as *mut System);
+        let ret = if let Some(process) = system.process(Pid(pid)) {
+            process as *const Process as CProcess
+        } else {
+            std::ptr::null()
+        };
+        Box::into_raw(system);
+        ret
+    }
 }
 
 /// Equivalent of iterating over [`Process::tasks()`][crate::Process#method.tasks].
@@ -326,13 +358,15 @@ pub extern "C" fn sysinfo_process_get_tasks(
 ) -> size_t {
     assert!(!process.is_null());
     if let Some(fn_pointer) = fn_pointer {
-        let process = process as *const Process;
-        for (pid, process) in unsafe { (*process).tasks.iter() } {
-            if !fn_pointer(*pid, process as *const Process as CProcess, data) {
-                break;
+        unsafe {
+            let process = process as *const Process;
+            for (pid, process) in (*process).tasks.iter() {
+                if !fn_pointer(pid.0, process as *const Process as CProcess, data) {
+                    break;
+                }
             }
+            (*process).tasks.len() as size_t
         }
-        unsafe { (*process).tasks.len() as size_t }
     } else {
         0
     }
@@ -343,7 +377,7 @@ pub extern "C" fn sysinfo_process_get_tasks(
 pub extern "C" fn sysinfo_process_get_pid(process: CProcess) -> pid_t {
     assert!(!process.is_null());
     let process = process as *const Process;
-    unsafe { (*process).pid() }
+    unsafe { (*process).pid().0 }
 }
 
 /// Equivalent of [`Process::parent()`][crate::Process#method.parent].
@@ -353,7 +387,7 @@ pub extern "C" fn sysinfo_process_get_pid(process: CProcess) -> pid_t {
 pub extern "C" fn sysinfo_process_get_parent_pid(process: CProcess) -> pid_t {
     assert!(!process.is_null());
     let process = process as *const Process;
-    unsafe { (*process).parent().unwrap_or_else(|| 0) }
+    unsafe { (*process).parent().unwrap_or(Pid(0)).0 }
 }
 
 /// Equivalent of [`Process::cpu_usage()`][crate::Process#method.cpu_usage].
@@ -391,7 +425,7 @@ pub extern "C" fn sysinfo_process_get_executable_path(process: CProcess) -> RStr
                 return c.into_raw() as _;
             }
         }
-        ::std::ptr::null()
+        std::ptr::null()
     }
 }
 
@@ -406,7 +440,7 @@ pub extern "C" fn sysinfo_process_get_root_directory(process: CProcess) -> RStri
                 return c.into_raw() as _;
             }
         }
-        ::std::ptr::null()
+        std::ptr::null()
     }
 }
 
@@ -421,7 +455,7 @@ pub extern "C" fn sysinfo_process_get_current_directory(process: CProcess) -> RS
                 return c.into_raw() as _;
             }
         }
-        ::std::ptr::null()
+        std::ptr::null()
     }
 }
 
